<?php

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;
use PHPMailer\PHPMailer\SMTP;

require __DIR__ . '/vendor/autoload.php';

use Twilio\Rest\Client;

// Prevent problems with iframes
ini_set('session.cookie_samesite', 'None');
// Start the session
session_start();

if (!$action = filter_input(INPUT_POST, 'action')) {
    echo json_encode(['is_error' => 1, 'message' => 'Invalid Request']);
    exit;
}

if ($action == 'submit-questions') {
    echo submitQuestions();
    exit;
} else if ($action == 'send-code') {
    echo sendCode();
    exit;
} else if ($action == 'verify-code') {
    echo verifyCode();
    exit;
}

function getAnswer($questions, $name) {
    foreach ($questions as $question) {
        if ($question["name"] == $name) {
            return $question["answer"];
        }
    }

    return null;
}

function getValueFromAssoc($assocArray, $searchKey) {
    foreach ($assocArray as $key => $value) {
        if ($searchKey == $key) {
            return $value;
        }
    }

    return null;
}

function submitQuestions() {
    // VerifyCode
    if (!$code = filter_input(INPUT_POST, 'code')) {
        return json_encode(['is_error' => 1, 'message' => 'Please Enter Code']);
    }

    if (empty($_COOKIE['code'])) {
        return json_encode(['is_error' => 1, 'message' => 'Code expired, Please resend code']);
    }

    if ($_COOKIE['code'] != $code) {
        return json_encode(['is_error' => 1, 'message' => 'Wrong Code']);
    }
    // VerifyCode

    if (!$questions = filter_input(INPUT_POST, 'questions', FILTER_DEFAULT, FILTER_REQUIRE_ARRAY)) {
        return json_encode(['is_error' => 1, 'message' => 'Please answer all questions']);
    }

    if (!$phone_number = filter_input(INPUT_POST, 'phone_number')) {
        return json_encode(['is_error' => 1, 'is_phone_error' => 1, 'message' => 'Phone Number not found']);
    }
    if (!$wh_url = filter_input(INPUT_POST, 'wh_url')) {
        return json_encode(['is_error' => 1, 'message' => 'Webhook URL not found.']);
    }

    // Check if all questions have answers
    foreach ($questions as $question) {
        if (empty($question['question']) || empty($question['answer'])) {
            return json_encode(['is_error' => 1, 'message' => 'Please answer all questions']);
        }
    }
    $qualified = 'True';
    if (getAnswer($questions, "CompanyWebsite") == 'N/A' || getAnswer($questions, "CompanySize") == 'Just me' || getAnswer($questions, "CompanyTurnover") == '$0 - $500K' || getAnswer($questions, "MonthlyBudget") == 'Less than $2,000') {
        $qualified = 'False';
    }

    $email_body = "";

    $email_body .= "Congratulations, you have a new proposal request. Here are the details:<br/><br/>";

    $email_body .= "<strong>Lead Details:</strong><br/>\n";
    $email_body .= "<ul>\n";
    $email_body .= "<li>First Name: " . getAnswer($questions, "FirstName") . "</li>";
    $email_body .= "<li>Last Name: " . getAnswer($questions, "LastName") . "</li>";
    $email_body .= "<li>Email: " . getAnswer($questions, "EmailAddress") . "</li>";
    $email_body .= "<li>Phone: " . str_replace(" ", "", getAnswer($questions, "PhoneNumber")) . "</li>";
    $email_body .= "</ul>\n";

    $email_body .= "<strong>Company Details:</strong><br/>\n";
    $email_body .= "<ul>\n";
    $email_body .= "<li>Company Name: " . getAnswer($questions, "CompanyName") . "</li>";
    $email_body .= "<li>Company Website: " . getAnswer($questions, "CompanyWebsite") . "</li>";
    $email_body .= "<li>Company Size: " . getAnswer($questions, "CompanySize") . "</li>";
    $email_body .= "<li>Company Turnover: " . getAnswer($questions, "CompanyTurnover") . "</li>";
    $email_body .= "<li>Monthly Budget: " . getAnswer($questions, "MonthlyBudget") . "</li>";
    $email_body .= "<li>Qualified Lead: " . $qualified . "</li>";
    $email_body .= "</ul>\n";

    $parts = parse_url($wh_url);
    parse_str($parts['query'], $params);

    $email_body .= "<strong>Campaign Details:</strong><br/>\n";
    $email_body .= "<ul>\n";
    $email_body .= "<li>UTM Industry: " . getValueFromAssoc($params, "utm_industry") . "</li>";
    $email_body .= "<li>UTM Source: " . getValueFromAssoc($params, "utm_source") . "</li>";
    $email_body .= "<li>UTM Medium: " . getValueFromAssoc($params, "utm_medium") . "</li>";
    $email_body .= "<li>UTM Campaign: " . getValueFromAssoc($params, "utm_campaign") . "</li>";
    $email_body .= "<li>UTM Campaign ID: " . getValueFromAssoc($params, "utm_campaign_id") . "</li>";
    $email_body .= "<li>UTM Content: " . getValueFromAssoc($params, "utm_content") . "</li>";
    $email_body .= "<li>UTM Ad Set ID: " . getValueFromAssoc($params, "utm_ad_set_id") . "</li>";
    $email_body .= "<li>UTM Term: " . getValueFromAssoc($params, "utm_term") . "</li>";
    $email_body .= "<li>UTM Ad ID: " . getValueFromAssoc($params, "utm_ad_id") . "</li>";
    $email_body .= "</ul>\n";

    $email_body .= "<strong>Technical Details:</strong><br/>\n";
    $email_body .= "<ul>\n";
    $email_body .= "<li>IP Address: " . getValueFromAssoc($params, "ip_address") . "</li>";
    $email_body .= "<li>User Agent: " . getValueFromAssoc($params, "user_agent") . "</li>";
    $email_body .= "<li>Event ID: " . getValueFromAssoc($params, "event_id") . "</li>";
    $email_body .= "<li>Referrer URL: " . getValueFromAssoc($params, "referrer_url") . "</li>";
    $email_body .= "<li>From URL: " . getValueFromAssoc($params, "from_url") . "</li>";
    $email_body .= "</ul>\n";

    // Success response from last step of email sending
    return sendEmail($email_body);
}

function sendCode() {
    if (!$phone_number = filter_input(INPUT_POST, 'phone_number')) {
        return json_encode(['is_error' => 1, 'message' => 'Phone Number not found']);
    }

    // Account SID and Auth Token from twilio.com/console
    // Test
    // $account_sid = 'AC8d4decbf13e7730d78c82db5720e4ada';
    // $auth_token = '0908a676561ca16b1496df6462e36b0d';
    // Live
    $account_sid = 'ACc6317bcfad5ee3f02a9c446af759af44';
    $auth_token = '6740a2329f69f89855e7739355c5b0f8';
    // Live - New
    // $account_sid = 'SKb8d0749fc4c8b36fa4bc1318c30e896d';
    // $auth_token = 'qBigY09CWQRu02uHqyVyaXzbPFyQPsJf';
    // In production, these should be environment variables. E.g.:
    // $auth_token = $_ENV["TWILIO_AUTH_TOKEN"]
    // A Twilio number you own with SMS capabilities
    // $twilio_number = "+15017122661";
    // $twilio_number = "61451562323"; // Twilio purchased number (Old)
    $twilio_number = "61480032323"; // Twilio purchased number

    try {
        $code = rand(100000, 999999);

        $client = new Client($account_sid, $auth_token);
        $client->messages->create(
                // Where to send a text message (your cell phone?)
                // '+15558675310',
                str_replace(" ", "", $phone_number),
                array(
                    'from' => $twilio_number,
                    'body' => 'Your Axis Social verification code is ' . $code . '.'
                )
        );
        setcookie("code", $code, time() + 600, "/");
        return json_encode(['is_error' => 0, 'message' => 'Verification code sent.', 'debug' => $code]);

        // Remove below line, only for testing (Uncomment above line)
        // return json_encode(['is_error' => 0, 'message' => 'Verification code sent.', 'code' => $code]);
    } catch (\Throwable $e) {
        return json_encode(['is_error' => 1, 'message' => 'Invalid Phone Number']);
    }
}

function sendGridSendEmail($toAddress, $fromName, $fromAddress, $subject, $htmlBody) {
    $request = [
        "personalizations" => [
            [
                "to" => [
                    ["email" => $toAddress, "name" => $toAddress]
                ]
            ]
        ],
        "from" => [
            "email" => $fromAddress,
            "name" => $fromName
        ],
        "subject" => $subject,
        "content" => [
            [
                "type" => "text/html",
                "value" => $htmlBody
            ]
        ]
    ];

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, "https://api.sendgrid.com/v3/mail/send");
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, ["content-type: application/json", "Authorization: Bearer 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"]);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($request));

    $result = curl_exec($ch);

    return $result;
}

function sendEmail($email_body) {
    if (!$wh_url = filter_input(INPUT_POST, 'wh_url')) {
        return json_encode(['is_error' => 1, 'message' => 'Webhook URL not found.']);
    }
    if (!$first_name = filter_input(INPUT_POST, 'first_name')) {
        return json_encode(['is_error' => 1, 'message' => 'First Name not found.']);
    }
    if (!$user_email = filter_input(INPUT_POST, 'user_email')) {
        return json_encode(['is_error' => 1, 'message' => 'Email not found.']);
    }

    try {

        $fromName = "Axis Social Leads";
        $fromAddress = "leads@axissocial.com.au";
        $subject = "Congrats, New Axis Social Lead!";

        sendGridSendEmail("matt@axissocial.com.au", $fromName, $fromAddress, $subject, $email_body);
        sendGridSendEmail("dan@axissocial.com.au", $fromName, $fromAddress, $subject, $email_body);

        file_get_contents($wh_url);
        unset($_COOKIE['code']);

        //thank page url
        if (!$questions = filter_input(INPUT_POST, 'questions', FILTER_DEFAULT, FILTER_REQUIRE_ARRAY)) {
            return json_encode(['is_error' => 1, 'message' => 'Please answer all questions']);
        }
        $thank_page = 'https://axissocial.com.au/request-thanks/';
        if (getAnswer($questions, "CompanyWebsite") == 'N/A' || getAnswer($questions, "CompanySize") == 'Just me' || getAnswer($questions, "CompanyTurnover") == '$0 - $500K' || getAnswer($questions, "MonthlyBudget") == 'Less than $2,000') {
            $thank_page = 'https://axissocial.com.au/not-yet/';
        }
        //end
        return json_encode(['is_error' => 0, 'message' => 'Thanks!', 'thank_page' => $thank_page]);
    } catch (\Throwable $e) {
        return json_encode(['is_error' => 1, 'message' => 'Email sending failed. There was some problem']);
    }
}

?>